@@ -6,7 +6,7 @@ use 5.016;
 use warnings;
 use utf8;
 
-our $VERSION = 1.002;
+our $VERSION = 1.003;
 
 use IP::Geolocation::MMDB::Metadata;
 use Math::BigInt 1.999806;
@@ -68,7 +68,7 @@ IP::Geolocation::MMDB - Read MaxMind DB files
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
@@ -213,15 +213,16 @@ None.
 
 =head1 DEPENDENCIES
 
-Requires libmaxminddb 1.2.0 or newer.
+Requires L<Alien::libmaxminddb> from CPAN.  Requires L<Math::BigInt> version
+1.999806, which is distributed with Perl 5.26 and newer.
 
-Requires L<Alien::libmaxminddb> from CPAN.  On Windows, L<Alien::MSYS> needs
-to be installed.  Requires L<Math::BigInt> version 1.999806, which is
-distributed with Perl 5.26 and newer.
+Requires libmaxminddb 1.2.0 or newer.
 
 Requires an IP to country, city or ASN database in the MaxMind DB file format
 from L<MaxMind|https://www.maxmind.com/> or L<DP-IP.com|https://db-ip.com/>.
 
+Windows is not supported.  Please do not ask for Windows support.
+
 =head1 INCOMPATIBILITIES
 
 None.
@@ -237,8 +238,6 @@ MMDB_DATA_TYPE_UINT64 values are put into Math::BigInt objects;
 
 MMDB_DATA_TYPE_UINT128 values are put into Math::BigInt objects;
 
-Some Windows versions do not support IPv6.
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2022 Andreas Vögele
